gatenlp.processing API documentation
Description: Package for annotators, and other things related to processing documents.

# Module `gatenlp.processing`

Package for annotators, and other things related to processing documents.

Expand source code

    """
    Package for annotators, and other things related to processing documents.
    """

## Sub-modules

`gatenlp.processing.annotator`

  Module with the base class and supporting functions for all annotators. Any callable that can be called by passing a document can be used as an …

`gatenlp.processing.client`

  Module that provides various Annotators which act as clients to REST annotation services.

`gatenlp.processing.executor`
`gatenlp.processing.gazetteer`

  This module provides Gazetteer classes which allow matching the text or the tokens of documents against gazetteer lists, lists of interesting texts or …

`gatenlp.processing.matcher`

  Module that defines classes for matchers other than gazetteers which match e.g. regular expressions of strings or annotations.

`gatenlp.processing.normalizer`

  Module that provides classes for normalizers. Normalizers are annotators which change the text of selected annotations or the entire text of the …

`gatenlp.processing.pipeline`

  Module that provides the Pipeline class. A Pipeline is an annotator which is configured to contain several annotators which get executed in sequence …

`gatenlp.processing.tokenizer`